@@ -7,7 +7,7 @@ use deno_core::error::type_error;
 use deno_core::error::uri_error;
 use deno_core::error::AnyError;
 use deno_core::include_js_files;
-use deno_core::op_sync;
+use deno_core::op;
 use deno_core::url::form_urlencoded;
 use deno_core::url::quirks;
 use deno_core::url::Url;
@@ -27,21 +27,12 @@ pub fn init() -> Extension {
       "01_urlpattern.js",
     ))
     .ops(vec![
-      ("op_url_parse", op_sync(op_url_parse)),
-      ("op_url_reparse", op_sync(op_url_reparse)),
-      (
-        "op_url_parse_search_params",
-        op_sync(op_url_parse_search_params),
-      ),
-      (
-        "op_url_stringify_search_params",
-        op_sync(op_url_stringify_search_params),
-      ),
-      ("op_urlpattern_parse", op_sync(op_urlpattern_parse)),
-      (
-        "op_urlpattern_process_match_input",
-        op_sync(op_urlpattern_process_match_input),
-      ),
+      op_url_parse::decl(),
+      op_url_reparse::decl(),
+      op_url_parse_search_params::decl(),
+      op_url_stringify_search_params::decl(),
+      op_urlpattern_parse::decl(),
+      op_urlpattern_process_match_input::decl(),
     ])
     .build()
 }
@@ -66,8 +57,8 @@ type UrlParts = String;
 
 /// Parse `UrlParseArgs::href` with an optional `UrlParseArgs::base_href`, or an
 /// optional part to "set" after parsing. Return `UrlParts`.
+#[op]
 pub fn op_url_parse(
-  _state: &mut deno_core::OpState,
   href: String,
   base_href: Option<String>,
 ) -> Result<UrlParts, AnyError> {
@@ -99,8 +90,8 @@ pub enum UrlSetter {
   Username = 9,
 }
 
+#[op]
 pub fn op_url_reparse(
-  _state: &mut deno_core::OpState,
   href: String,
   setter_opts: (UrlSetter, String),
 ) -> Result<UrlParts, AnyError> {
@@ -168,8 +159,8 @@ fn url_result(
   )
 }
 
+#[op]
 pub fn op_url_parse_search_params(
-  _state: &mut deno_core::OpState,
   args: Option<String>,
   zero_copy: Option<ZeroCopyBuf>,
 ) -> Result<Vec<(String, String)>, AnyError> {
@@ -187,10 +178,9 @@ pub fn op_url_parse_search_params(
   Ok(params)
 }
 
+#[op]
 pub fn op_url_stringify_search_params(
-  _state: &mut deno_core::OpState,
   args: Vec<(String, String)>,
-  _: (),
 ) -> Result<String, AnyError> {
   let search = form_urlencoded::Serializer::new(String::new())
     .extend_pairs(args)
